@@ -13,6 +13,7 @@ class QolsysTableTcc(QolsysTable):
         self._uri = "content://com.qolsys.qolsysprovider.TccContentProvider/tcc"
         self._table = "tcc"
         self._abort_on_error = False
+        self._implemented = True
 
         self._columns = [
             "tableName",
@@ -20,11 +21,3 @@ class QolsysTableTcc(QolsysTable):
         ]
 
         self._create_table()
-
-    def insert(self, data: dict) -> None:
-        # panel sends content://com.qolsys.qolsysprovider.PowerGDeviceContentProvider/powerg_device' twice
-        self._cursor.execute(f"INSERT OR IGNORE INTO {self.table} (tableName,counter) VALUES (?,?)", (
-            data.get("tableName"),
-            data.get("counter", "")))
-
-        self._db.commit()
