@@ -353,7 +353,7 @@ class QolsysPanel(QolsysObservable):
     def parse_iq2meid_message(self, data: dict) -> bool:  # noqa: C901, PLR0912, PLR0915
 
         eventName = data.get("eventName")
-        dbOperation = data.get("dbOperation")
+        dbOperation = data.get("dbOperation","")
         uri = data.get("uri")
 
         match eventName:
@@ -361,6 +361,9 @@ class QolsysPanel(QolsysObservable):
             case "stopScreenCapture":
                 pass
 
+            case "primaryDisconnect":
+                LOGGER.info("Main Panel Disconnect")
+
             case "dbChanged":
 
                 match dbOperation:
@@ -508,6 +511,11 @@ class QolsysPanel(QolsysObservable):
                                 if scene is not None and isinstance(node, QolsysScene):
                                     scene.update(content_values)
 
+                            # Update Trouble Conditions
+                            case self.db.table_trouble_conditions:
+                                self.db.table_trouble_conditions.update(selection,selection_argument,content_values)
+                                # No action needed
+
 
                             case _:
                                 LOGGER.debug("iq2meid updating unknow uri:%s", uri)
@@ -799,7 +807,7 @@ class QolsysPanel(QolsysObservable):
 
         # Create sensors array
         for zone_info in zones_list:
-            zones.append(QolsysZone(zone_info))
+            zones.append(QolsysZone(zone_info,self._settings))
 
         return zones
 
